==> centreon-web-24.04.19.tar.gz: centreon-web-24.04.19/tests/php/Core/Notification/Infrastructure/API/FindNotifiableResources/FindNotifiableResourcesPresenterStub.php <==
<?php

/*
 * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : user@centreon.com
 *
 */

declare(strict_types=1);

namespace Tests\Core\Notification\Infrastructure\API\FindNotifiableResources;

use Core\Application\Common\UseCase\AbstractPresenter;
use Core\Application\Common\UseCase\ResponseStatusInterface;
use Core\Infrastructure\Common\Presenter\PresenterFormatterInterface;
use Core\Notification\Application\UseCase\FindNotifiableResources\{
    FindNotifiableResourcesPresenterInterface as PresenterInterface,
    FindNotifiableResourcesResponse
};

class FindNotifiableResourcesPresenterStub extends AbstractPresenter implements PresenterInterface
{
    /** @var FindNotifiableResourcesResponse|null */
    public ?FindNotifiableResourcesResponse $response = null;

    /** @var ResponseStatusInterface|null */
    public ?ResponseStatusInterface $responseStatus = null;

    public function __construct(protected PresenterFormatterInterface $presenterFormatter) {
        parent::__construct($presenterFormatter);
    }

    /**
     * @inheritDoc
     */
    public function presentResponse(FindNotifiableResourcesResponse|ResponseStatusInterface $response): void
    {
        if ($response instanceof ResponseStatusInterface) {
            $this->responseStatus = $response;
        } else {
            $this->response = $response;
        }
    }
}

==> centreon-web-24.10.21.tar.gz: centreon-web-24.10.21/tests/php/Core/Notification/Infrastructure/API/FindNotifiableResources/FindNotifiableResourcesPresenterStub.php <==
<?php

/*
 * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Tests\Core\Notification\Infrastructure\API\FindNotifiableResources;

use Core\Application\Common\UseCase\AbstractPresenter;
use Core\Application\Common\UseCase\ResponseStatusInterface;
use Core\Infrastructure\Common\Presenter\PresenterFormatterInterface;
use Core\Notification\Application\UseCase\FindNotifiableResources\{
    FindNotifiableResourcesPresenterInterface as PresenterInterface,
    FindNotifiableResourcesResponse
};

class FindNotifiableResourcesPresenterStub extends AbstractPresenter implements PresenterInterface
{
    /** @var FindNotifiableResourcesResponse|null */
    public ?FindNotifiableResourcesResponse $response = null;

    /** @var ResponseStatusInterface|null */
    public ?ResponseStatusInterface $responseStatus = null;

    public function __construct(protected PresenterFormatterInterface $presenterFormatter)
    {
        parent::__construct($presenterFormatter);
    }

    /**
     * @inheritDoc
     */
    public function presentResponse(FindNotifiableResourcesResponse|ResponseStatusInterface $response): void
    {
        if ($response instanceof ResponseStatusInterface) {
            $this->responseStatus = $response;
        } else {
            $this->response = $response;
        }
    }
}
